@@ -1,5 +1,5 @@
 package WebService::Braintree;
-$WebService::Braintree::VERSION = '0.3.1';
+$WebService::Braintree::VERSION = '0.3';
 
 use 5.006;
 use strict;
@@ -37,7 +37,7 @@ WebService::Braintree - A Client Library for wrapping the Braintree Payment Serv
 =head2 FORK
 
 This is a fork of the original vendor-issued L<Net::Braintree>.  While the
-original is deprecated, it continues to work. However, it contains a number
+original is depreacted, it continues to work. However, it contains a number
 of code-style and maintainability problems.  This fork was produced to
 address some of those problems and to provide a community driven basis for
 going forward.
@@ -51,7 +51,7 @@ L<https://developers.braintreepayments.com/ruby/sdk/server/overview>.
 
 You can also look over the test suite for guidance of usage, especially the
 C<xt/sandbox> tests.  Not all of these tests work (ones marked
-C<todo_skip>).  This is because they are an adaptation of code used against
+C<todo_skip>.  This is because they are an adaptation of code used against
 Braintree's private integration server.  Care has been taken that the same
 sandbox tests that fail in this module also fail for L<Net::Braintree>, and
 in the same manner.
@@ -78,7 +78,7 @@ Patches welcome!
 
 =item Sandbox tests fail
 
-Some of this is likely because the sandbox account needs to be set
+Some of this is likely needed because the sandbox account needs to be set
 up just right, and some may be because the paypal test integration server
 is emulating stateful transactions.
 
@@ -93,8 +93,7 @@ difficult to understand:
 =item L<WebService::Braintree::ResultObject>
 
 This class is now the only one that is not immutable in the codebase.
-Unpicking how to make this immutable is problematic.  Once this package is
-immutable a port to L<Moo> is likely straightforward.
+Unpicking how to make this mutable is problematic.
 
 =item L<WebService::Braintree::AdvancedSearchFields>
 
@@ -110,13 +109,6 @@ immutable a port to L<Moo> is likely straightforward.
 
 =back
 
-Also, having stared at the internals of some objects in the perl debugger
-for a bit, I fear there may be memory leaks, but I have not investigated
-this closely.  It's also possible that the way that several of the above
-methods use a C<$field> variable in package lexical scope that this module
-may not be fork-safe.  These concerns also apply to L<Net::Braintree> (only
-it has a bigger memory footprint).
-
 =back
 
 =head2 ACKNOWLEDGEMENTS
